//! Common errors when handling cryptographic functions

/// Crypto errors
#[derive(::thiserror::Error, Debug, Copy, Clone)]
pub enum Error {
    /// Error while parsing key material
    #[error("can't parse key")]
    Parsing,
    /// Not enough data
    #[error("not enough data")]
    NotEnoughData,
    /// buffer too small
    #[error("buffer too small")]
    InsufficientBuffer,
    /// Wrong Key type found.
    /// You might have passed rsa keys where x25519 was expected
    #[error("wrong key type")]
    WrongKey,
    /// Unsupported key exchange for this key
    #[error("unsupported key exchange")]
    UnsupportedKeyExchange,
    /// Unsupported cipher
    #[error("unsupported cipher")]
    UnsupportedCipher,
    /// Can not decrypt. Either corrupted or malicious data
    #[error("decrypt: corrupted data")]
    Decrypt,
}
